<video  class="video-js vjs-default-skin wikihow2zim{% if classes%} {{ classes }}{% endif %}"
        {% if poster %}poster="{{ poster }}"{% endif %}
        {% if width %}width="{{ width }}"{% endif %}
        {% if height%}height="{{ height }}"{% endif %}
        {% if controls %}controls="controls"{% endif %}
        {% if autoplay %}autoplay="autoplay"{% endif %}
        {% if muted %}muted="muted"{% endif %}
        {% if loop %}loop="loop"{% endif %}
        {% if preload %}preload="auto"{% endif %}
        {% if playsinline %}playsinline="playsinline"{% endif %}
        {% if alt %}alt="{{ alt }}"{% endif %}>
    <source src="{{ path }}" type="video/{{ video_format }}" />
</video>
